@@ -6,7 +6,7 @@ pub type MousePosition = (i32, i32);
 /// MouseButton.
 pub type MouseButton = usize;
 
-#[derive(Debug, PartialEq, Default)]
+#[derive(Debug, PartialEq, Default, Clone)]
 /// A simple structure containing the current mouse coordinates and the
 /// state of each mouse button that we can query. Currently, Windows and
 /// Linux provide nice ways to query five mouse buttons. Since button
